#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Cloudbase Agent LlamaIndex Package.

This is a namespace package that extends the base Cloudbase Agent package with LlamaIndex integration.
"""

# Declare this as a namespace package to allow other cloudbase_agent subpackages to coexist
__path__ = __import__('pkgutil').extend_path(__path__, __name__)

__all__ = []
